/*
  SPDX-FileCopyrightText: 2023-2024 Laurent Montel <montel.org>

  SPDX-License-Identifier: GPL-2.0-or-later
*/

#pragma once

#include <QString>
namespace TextSpeechToText
{
namespace TextSpeechToTextUtil
{
[[nodiscard]] QString groupTranslateName();
[[nodiscard]] QString engineTextToSpeechName();
[[nodiscard]] QString defaultEngineName();
};
}
