/*
  SPDX-FileCopyrightText: 2022-2024 Laurent Montel <montel@kde.org>

  SPDX-License-Identifier: GPL-2.0-or-later
*/

#pragma once

#include <QString>

namespace DeeplEngineUtil
{
[[nodiscard]] QString groupName();
[[nodiscard]] QString freeLicenseKey();
[[nodiscard]] QString apiGroupName();
[[nodiscard]] QString translatorGroupName();
};
