/*
   SPDX-FileCopyrightText: 2019-2024 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: GPL-2.0-or-later
*/

#pragma once

#include <QObject>

class LanguageToolListOfLanguagesParserTest : public QObject
{
    Q_OBJECT
public:
    explicit LanguageToolListOfLanguagesParserTest(QObject *parent = nullptr);
    ~LanguageToolListOfLanguagesParserTest() override = default;
};
